@@ -100,16 +100,6 @@ impl PdfColor {
 
     /// Returns this color as a decimal value equivalent to 32-bit hexadecimal 0xFFRRGGBB.
     #[inline]
-    #[cfg(target_arch = "wasm32")]
-    pub(crate) fn color(&self) -> FPDF_DWORD {
-        let (f, r, g, b) = self.color_components();
-
-        ((f << 24) | (r << 16) | (g << 8) | b) as FPDF_DWORD
-    }
-
-    /// Returns this color as a decimal value equivalent to 32-bit hexadecimal 0xFFRRGGBB.
-    #[inline]
-    #[cfg(not(target_arch = "wasm32"))]
     pub(crate) fn color(&self) -> FPDF_DWORD {
         let (f, r, g, b) = self.color_components();
 
